@@ -16,7 +16,9 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 import os
 import uuid
 import sys
@@ -225,8 +227,10 @@ FILES = {
             {
                 'conditions': {},
                 'content': {
-                    'dynamic_ownership': 0,
-                    'save_image_format': '"lzop"',
+                    'dynamic_ownership': 1,
+                    'save_image_format': '"gzip"',
+                    'user': '"qemu"',
+                    'group': '"qemu"',
                     'remote_display_port_min': 5900,
                     'remote_display_port_max': 6923,
                     'max_core': '"unlimited"',
