@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import division
 
 # Copyright 2013 Miguel Angel Ajo
 #
